@@ -243,6 +243,7 @@ bool FMStatic::copy(const QList<QUrl> &urls, const QUrl &destinationDir)
 
 bool FMStatic::group(const QList<QUrl>& urls, const QUrl& destinationDir, const QString &name)
 {
+
     if(!FMStatic::fileExists(QUrl(destinationDir.toString() + QStringLiteral("/") + name)))
     {
         QDir(destinationDir.toLocalFile()).mkdir(name);
@@ -586,9 +587,9 @@ const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
                 {FMH::MODEL_KEY::SUFFIX, file.completeSuffix()},
                 {FMH::MODEL_KEY::LABEL, path.toString() == HomePath ? QStringLiteral("Home") : file.fileName()},
                 {FMH::MODEL_KEY::NAME, file.fileName()},
-                {FMH::MODEL_KEY::DATE, file.birthTime().toString(Qt::TextDate)},
-                {FMH::MODEL_KEY::MODIFIED, file.lastModified().toString(Qt::TextDate)},
-                {FMH::MODEL_KEY::LAST_READ, file.lastRead().toString(Qt::TextDate)},
+                {FMH::MODEL_KEY::DATE, file.birthTime(QTimeZone::UTC).toString(Qt::TextDate)},
+                {FMH::MODEL_KEY::MODIFIED, file.lastModified(QTimeZone::UTC).toString(Qt::TextDate)},
+                {FMH::MODEL_KEY::LAST_READ, file.lastRead(QTimeZone::UTC).toString(Qt::TextDate)},
                 {FMH::MODEL_KEY::MIME, mime},
                 {FMH::MODEL_KEY::SYMLINK, file.symLinkTarget()},
                 {FMH::MODEL_KEY::IS_SYMLINK, QVariant(file.isSymLink()).toString()},
