@@ -1,25 +1,33 @@
+
 #include "tagslist.h"
 #include "tagging.h"
+#include <QTimer>
 
 TagsList::TagsList(QObject *parent)
-    : MauiList(parent) {}
+    : MauiList(parent)
+    ,m_refreshTimer(new QTimer(this))
+{
+    m_refreshTimer->setInterval(1000);
+    m_refreshTimer->setSingleShot(true);
+
+    connect(m_refreshTimer, &QTimer::timeout, this, &TagsList::setList);
+}
 
 void TagsList::setList()
 {
     Q_EMIT this->preListChanged();
-    
-    if (this->m_urls.isEmpty()) {
+    this->list.clear();
+
+    if (this->m_urls.isEmpty())
+    {
         this->list = FMH::toModelList(Tagging::getInstance()->getAllTags(this->strict));
         
-    } else if(this->m_urls.size() > 1) {
-        this->list.clear();
-        
-    } else {
-        this->list.clear();
+    }else
+    {
         this->list = std::accumulate(this->m_urls.constBegin(), this->m_urls.constEnd(), FMH::MODEL_LIST(), [this](FMH::MODEL_LIST &list, const QString &url) {
-                list << FMH::toModelList(Tagging::getInstance()->getUrlTags(url, this->strict));
-                return list;
-    });
+            list << FMH::toModelList(Tagging::getInstance()->getUrlTags(url, this->strict));
+            return list;
+        });
     }
     
     Q_EMIT this->tagsChanged();
@@ -28,7 +36,7 @@ void TagsList::setList()
 
 void TagsList::refresh()
 {
-    this->setList();
+    m_refreshTimer->start();
 }
 
 bool TagsList::insert(const QString &tag)
@@ -46,8 +54,6 @@ void TagsList::insertToUrls(const QString &tag)
 
     for (const auto &url : std::as_const(this->m_urls))
         Tagging::getInstance()->tagUrl(url, tag);
-
-    this->refresh();
 }
 
 void TagsList::updateToUrls(const QStringList &tags) //if there is only one url update the tags if there are more than one url then add the new tags
@@ -68,8 +74,6 @@ void TagsList::updateToUrls(const QStringList &tags) //if there is only one url
             }
         }
     }
-
-    this->refresh();
 }
 
 void TagsList::removeFromUrls(const int &index)
@@ -163,7 +167,7 @@ void TagsList::setUrls(const QStringList &value)
 
 void TagsList::append(const QString &tag)
 {
-    this->append(FMH::MODEL {{FMH::MODEL_KEY::TAG, tag}});
+    this->append(FMH::MODEL {{FMH::MODEL_KEY::TAG, tag}, {FMH::MODEL_KEY::ICON, QStringLiteral("tag")}});
 }
 
 void TagsList::appendItem(const QVariantMap &tag)
@@ -197,8 +201,28 @@ bool TagsList::contains(const QString &tag)
 
 void TagsList::componentComplete()
 {
-    connect(Tagging::getInstance(), &Tagging::tagged, this, &TagsList::appendItem);    
+    connect(Tagging::getInstance(), &Tagging::tagged, [this](QVariantMap)
+            {
+                if(this->m_urls.isEmpty())
+                {
+                    this->refresh();
+                }
+            });
+
     connect(Tagging::getInstance(), &Tagging::tagRemoved, this, &TagsList::refresh);
+
+
+    connect(Tagging::getInstance(), &Tagging::urlTagged, [this](QString url, QString)
+            {
+                if(m_urls.contains(url))
+                    this->refresh();
+            });
+
+    connect(Tagging::getInstance(), &Tagging::urlTagRemoved, [this](QString, QString url)
+            {
+                if(m_urls.contains(url))
+                    this->refresh();
+            });
     
     connect(this, &TagsList::urlsChanged, this, &TagsList::setList);
     connect(this, &TagsList::strictChanged, this, &TagsList::setList);
