@@ -5,6 +5,7 @@
 
 #include <MauiKit4/Core/mauilist.h>
 
+class QTimer;
 /**
  * @brief The TagsList class
  * A model of the system tags, ready to be consumed by QML. This model has basic support for browsing, associating, adding and removing tags.
@@ -61,6 +62,8 @@ private:
 
     void append(const FMH::MODEL &tag);
 
+    QTimer *m_refreshTimer;
+
 Q_SIGNALS:
     void strictChanged();
     void urlsChanged();
